#ifndef MAINWINDOWUI_H
#define MAINWINDOWUI_H

#include <QWidget>
#include <qipdialogbox.h>
#include <QLabel>
#include <QPushButton>
#include <QGridLayout>
#include <QVBoxLayout>
#include <QGroupBox>
#include <QSpinBox>
#include <QTextEdit>
#include <QTabWidget>

#include "tmstatistics.h"
#include "wfdisplay.h"
#include "hkdisplay.h"
#include "lfrspectrogram.h"

class MainWindowUI : public QWidget
{
    Q_OBJECT
public:
    explicit MainWindowUI(QWidget *parent = 0);

    void setTCTMServerAddressIP(QString address);
    QString getTMEchoServerAddress();
    int getTMPort();
    int getTCPort();
    void displayOnConsole(QString message);

    QTabWidget *spwTabWidget;
    QWidget* spwTabWidgetPage0;
    QWidget* spwTabWidgetPage1;
    QWidget* spwTabWidgetPage2;
    QWidget* spwTabWidgetPage3;
    QWidget* spwTabWidgetPage4;
    QWidget* spwTabWidgetPage5;
    QWidget* spwTabWidgetPage6;
    QWidget* spwTabWidgetPage7;

    TMStatistics* tmStatistics;

    WFDisplay* wfDisplay;
    WFPage* wfPageBurst;
    WFPage* wfPageSBM1;
    WFPage* wfPageSBM2;
    HKDisplay* hkDisplay;
    LFRSpectrogram* lfrSpectrogam;

    QWidget* widget_spectrogram;

    QPushButton *button_openServerTCTM;
    QPushButton *button_testServerTCTM;
    QPushButton *button_openSocketEchoServer;
    QPushButton *button_TCAcknowledgement;
    QPushButton *button_TCRejection;
    QPushButton *button_GSEHK;
    QPushButton *button_clearConsole;
    QPushButton *button_resetStatistics;

    QIPDialogBox *serverTMEchoDialogBox;

    QSpinBox *spinbox_serverTMEchoPort;
    
signals:
    
public slots:
    void clearConsole();
    void totalOfBytesHasChanged(unsigned int nbBytes);
    void totalOfPacketsHasChanged(unsigned int nbPackets);

private:
    QLabel *label_serverTMEcho;
    QLabel *label_serverTMEchoPort;
    QLabel *label_TMServerPort;
    QLabel *label_TCServerPort;
    QLabel *label_currentTCTMServer;
    QLabel *label_currentTCTMServerIP;
    QLabel *label_totalOfBytes;
    QLabel *label_totalOfPackets;

    QTextEdit *console;

    QSpinBox *spinbox_TMServerPort;
    QSpinBox *spinbox_TCServerPort;

    QGroupBox *groupbox_TMEcho;
    QGroupBox *groupbox_ports;
    QGroupBox *groupbox_TMToForeignGSETester;

    QVBoxLayout *layout_TMEcho;
    QVBoxLayout *layout_TMToForeignGSETester;
    QVBoxLayout *layout_overallLayout;

    QGridLayout *mainLayout;
    QGridLayout *layout_ports;
    
};

#endif // MAINWINDOWUI_H
